Re: [PATCH] fetch-pack: speed up loading of refs via commit graph
- From
Junio C Hamano <gitster@pobox.com>
- Date
- Aug 5, 2021, 16:26 UTC
- Message-ID
- <xmqqtuk3luwc.fsf@gitster.g>
- In-Reply-To
- <YQvRTpJ0NGakTy9W@ncase>
Patrick Steinhardt <ps@pks.im> writes:
> I've put some more time into this. If rebased on top of v4 of [1], then > we can also use `parse_commit_in_graph_gently()` to further speed this > up from 15.8 seconds to 11.6 seconds with below patch. It's the same > memory/speed tradeoff as I'm doing in [1].
Sounds good.
> I guess I'd still like to treat both series separately for now given > that [1] is more involved compared to this patch series here. I'll then > do a follow-up when (if?) both series have landed.
During the pre-release freeze (cf. https://tinyurl.com/gitCal), new topics will not "land" anywhere so you have two weeks or so to stabilize the base topic. I would prefer not to have to worry about inter-dependent multiple topics anyway, especially the ones that are not relevant to the upcoming release during a pre-release period.
Thanks.